Utilities
~~~~~~~~~

These modules contain additional utilities, which may be useful for developers.

Such utilities include the MOOP utilities, the error checks, and the
MOOP checks.

.. code-block:: python

    from parmoo.utilities import moop_utils
    from parmoo.utilities import error_checks
    from parmoo.core import moop_checks

.. automodule:: utilities.moop_utils
..    :members: utilities/moop_utils

.. autofunction:: lex_leq

.. autofunction:: approx_equal

.. autofunction:: updatePF

.. autofunction:: to_array

.. autofunction:: from_array

.. automodule:: utilities.error_checks
..    :members: utilities/error_checks

.. autofunction:: xerror

.. autofunction:: check_names

.. autofunction:: gradient_error

.. automodule:: core.moop_checks
..    :members: core/moop_checks

.. autofunction:: check_sims
